.. _dep-0000:

DEP 0 - Index of DebOps Enhancement Proposals
=============================================

:DPG:          0
:Title:        Index of DebOps Enhancement Proposals
:Author:       Maciej Delmanowski
:Status:       Active
:Type:         Process
:Created:      2018-04-19
:Post-History: none


Introduction
------------

This document provides an index of the DebOps Enhancement Proposals and can be
used as a quick reference for finding active or deprecated DEPs. It is also
used to track numbers assigned to future DEPs.


Process DEPs
------------

- :ref:`dep-0001`
- :ref:`dep-0002`
- :ref:`dep-0003`
- :ref:`dep-0012`


Copyright
---------

.. code-block:: none

   Copyright (C) 2018 Maciej Delmanowski <drybjed@gmail.com>
   Copyright (C) 2018 DebOps https://debops.org/

   This document is part of DebOps.

   DebOps is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 3, as
   published by the Free Software Foundation.

   DebOps is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with DebOps. If not, see https://www.gnu.org/licenses/.

..
   vim: tw=72:
